<?php
// Software released under the General Public License (version 2 or later), available at
// http://www.gnu.org/copyleft/gpl.html

require_once("approach/astronomy/solarsystem/SolarSystemConstants.php");
require_once("approach/astronomy/solarsystem/ephemeris/EphemerisEngine.php");

/******************************************************************************
Utilisation of Steve Moshier's aa-56 program

@license  GPL
@author   <a href="http://www.tig12.net">Thierry Graff</a>
@history  2007.11.05, 19h16 : Creation
********************************************************************************/

class aa56 implements EphemerisEngine{
  
  /** correspondance between SolarSystem constants and aa56 object numbers */
  private static $code_matches = array(
    SolarSystemConstants::SUN => 0,
    SolarSystemConstants::MERCURY => 1,
    SolarSystemConstants::VENUS => 2,
    SolarSystemConstants::MOON => 3,
    SolarSystemConstants::MARS => 4,
    SolarSystemConstants::JUPITER => 5,
    SolarSystemConstants::SATURN => 6,
    SolarSystemConstants::URANUS => 7,
    SolarSystemConstants::NEPTUNE => 8,
    SolarSystemConstants::PLUTO => 9,
  );
  
  
  //********************* compute ******************************
  /**
    Computations using "aa" program of S. Moshier
  */
  public static function compute($jd, $what, $options=array()){
    // Prepare the command to call binary executable
    $os = 'linux'; // todo : compute
    $moshier_path = G::get('dir_data') . '/approach/astronomy/ephemeris/moshier';
    $command = $moshier_path . '/aa_' . $os . ' ';
    //
    $res = array();
    for($i=0; $i < count($what); $i++){
      if(!isset(self::$code_matches[$what[$i]])) continue;
      $moshierIndex = self::$code_matches[$what[$i]];
      $planet = $what[$i];
      $moshierJD = sprintf( "%.12f", $jd );
      // build the call arguments : jd planetCode
      $args = $moshierJD . ' ' . $moshierIndex;
      unset($output);
      exec($command . $args, $output);
//echo "<pre>"; print_r($output); echo "</pre>";
      switch($planet){
        case SolarSystemConstants::SUN :
          $lineNb = 2;
          $pattern = '/^ecliptic long (\d+\.\d+) lat (-?\d+\.\d+).*$/';
        break;
        case SolarSystemConstants::MOON :
          $lineNb = 4;
          $pattern = '/^Apparent geocentric longitude\s+(\d+\.\d+)\s+deg\s+latitude\s+(-?\d+\.\d+) deg.*$/';
        break;
        default :
          $lineNb = 2;
          $pattern = '/^ecliptic long (\d+\.\d+) lat (-?\d+\.\d+).*$/';
        break;
      }
      $line = trim($output[$lineNb]);
      preg_match($pattern, $line, $matches);
//echo "<pre>"; print_r($matches); echo "</pre>";
      $res['planets'][$planet]['x1'] = $matches[1];
      $res['planets'][$planet]['x2'] = $matches[2];
      //
      }
    return $res;
  }// end compute
  
  
}//end class



?>
