<?php 
// Software released under the General Public License (version 2 or later), available at
// http://www.gnu.org/copyleft/gpl.html
/****************************************************************************************
Contains functions to display HTML tags.

@license  GPL
@author   <a href="http://www.tig12.net">Thierry Graff</a>
@history 2002.10.03 : Creation
@history 2006.02.04 : Adding FORM() ; lowercase HTML tags
****************************************************************************************/

//******************** AHREF *******************************
/**
  Builds a A HREF tag.
  @param $ref Value of HREF attribute.
  @param $text Text used for the display ; if absent, $ref is used.
  @param $otherAttrs Other attributes of the tag.
*/
function AHREF($ref, $text="", $otherAttrs=""){
  if (!$text) $text = $ref;
  $strRes = "<a href=\"$ref\"";
  if($otherAttrs) $strRes .= " $otherAttrs";
  $strRes .= ">$text</a>";
  return $strRes;
} // end AHREF


//******************** ANAME *******************************
/**
  Builds a A NAME tag.
  @param $name Value of NAME attribute.
  @param $text Text used for the display.
*/
function ANAME($name, $text=""){
  return "<a name=\"$name\">$text</a>";
} // end ANAME


//******************** B *******************************
/**
  Builds a B tag.
  If $arg is not an array, just builds a B tag around $arg.
  If $arg is an array, returns an array with all elements surrounded by a B tag.
  Works only for a 1 dim array.
*/
function B($arg){
  if(is_array($arg)){
    for($i = 0; $i < count($arg); $i++){
      $arg[$i] = "<b>" . $arg[$i] . "</b>";
    }
    return $arg;
  }
  else return "<b>" . $arg . "</b>";
} // end B


//******************** CENTER *******************************
/**
  Builds a CENTER tag.
  If $arg is not an array, just builds a CENTER tag around $arg.
  If $arg is an array, returns an array with all elements surrounded by a CENTER tag.
  Works only for a 1 dim array.
*/
function CENTER($arg){
  if(is_array($arg)){
    for($i = 0; $i < count($arg); $i++){
      $arg[$i] = "<center>" . $arg[$i] . "</center>";
    }
    return $arg;
  }
  else return "<center>" . $arg . "</center>";
} // end CENTER


//******************** DIV *******************************
// written udiv because of spip div function : spip/ecrire/inc/filtres.php:2582
/**
  Encloses a string in a DIV tag, which may contain attributes. */
  function uDIV($str, $attrs=""){
    if($attrs) $attrs = " $attrs"; // to avoid a useless space
    return "<div$attrs>" . $str . "</div>";
} // end DIV


//******************** FORM *******************************
/** Encloses a string in a FORM tag. */
function FORM($contents, $action, $method, $otherAttrs=''){
  $strRes = "<form action=\"$action\" method=\"$method\"";
  if($otherAttrs != '') $strRes .= " $otherAttrs";
  $strRes .= ">\n";
  $strRes .= $contents;
  $strRes .= "</form>\n";
  return $strRes;
  if($attrs) $attrs = " $attrs"; // to avoid a useless space
  return "<div$attrs>" . $str . "</div>";
} // end DIV


//******************** H1, H2, H3 *******************************
/** Encloses a string in a H1 tag. */
function H1($str){ return "<h1>" . $str . "</h1>\n"; }
/** Encloses a string in a H2 tag. */
function H2($str){ return "<h2>" . $str . "</h2>\n"; }
/** Encloses a string in a H3 tag. */
function H3($str){ return "<h3>" . $str . "</h3>\n"; }
/** Encloses a string in a H4 tag. */
function H4($str){ return "<h4>" . $str . "</h4>\n"; }


//******************** I *******************************
/** Encloses a string in a I tag. */
function I($str){
  return "<i>$str</i>";
} // end I


//******************** IMG *******************************
/**
  Builds an IMG tag. 
  === WARNING === $alt parameter generates also a 'title' attribute
  @todo  put border into style attribute
*/
function IMG($url, $border=0, $alt="", $otherTags=""){
 $altAttr = "";
 if($alt) $altAttr = " alt=\"$alt\" title=\"$alt\"";
 if($otherTags) $otherTags = " $otherTags";
return "<img src=\"$url\" border=\"$border\"$altAttr$otherTags>";
}// end IMG


//******************** INPUT *******************************
/** Builds a INPUT tag. */
function INPUT($type, $name, $value='', $otherAttrs=''){
  $strRes = "<input type=\"$type\" name=\"$name\"";
  if($value !== "") $strRes .= " value=\"$value\""; // operator !== to distinguish " " from 0.
  if($otherAttrs != "") $strRes .= " $otherAttrs";
  $strRes .= ">";
  return $strRes . "\n";
} // end INPUT


//******************** LI *******************************
/** Encloses a string in a LI tag. */
function LI($str, $otherAttrs=''){
  $strRes = "<li";
  if($otherAttrs != '') $strRes .= " $otherAttrs";
  $strRes .= ">$str</li>\n";
  return $strRes;
}


 //******************** PRE *******************************
/** Encloses a string in a PRE tag. */
 function PRE($str){ return "<pre>\n$str\n</pre>\n"; }


//******************** SCRIPT *******************************
/**
  Builds a SCRIPT tag.
  @param $src Value of SRC attribute.
  @param $content Content of the tag (written between "<SCRIPT>" and "</SCRIPT>").
  @param $language Value of LANGUAGE attribute.
  @param $onClick Value of ONCLICK attribute.
*/
function SCRIPT($src, $content="", $language="JavaScript", $onClick=""){
  if($onClick) $attrOnClick = " onClick=\"" . $onclick . "\"";
  else $attrOnClick="";
  return "<script language=\"$language\" src=\"$src\"$attrOnClick>$content</script>\n";
} // end SCRIPT


//******************** TABLE *******************************
/**
  Builds a html TABLE displaying n arrays.
  It displays one per line for an horizontal layout or one per column for a vertical layout.
  If the arrays lengths are different, the cells are filled with &nbsp;
  @param $a A string, or a 1 or 2 dim array containing the data.
                - if $a is a string, condsidered as the content of the unique cell.
                - if $a is a 1 dim array (ex : a = array(1, 2, 3)), the table will contain
                only one row or column (depending on $layout).
                - Ex of $a for a 2 dim array : 
                $a = array(array(0, 1, 2), array(1, 5, "lkjh"), array(15, 4, 8)).
  @param $attrs Attributes for tag TABLE.
  @param $tdAttr Attributes to put in TD tags;
                If $tdAttr is a String, this string is used as attribute for all TDs.
                Otherwise, $tdAttr must be an array <b>of the same dimension as $a</b>, 
                (for a horizontal or a vertical layout).
  @param $layout Layout used in this table - horizontal or vertical ; 
                can be anything starting by "h" or "v".
  @throws IllegalArgumentException if <code>$layout</code> is incorrect
*/
function TABLE($a, $attrs="", $tdAttr="valign='top'", $layout="h"){
  $layout=substr(strToLower($layout), 0, 1);
  if($layout != "h" && $layout != "v")
    throw new IllegalArgumentException("Wrong parameter \$layout", "TABLE", "htmlTags.php");
  //
  // Transform $a to a 2 dim array if necessary
  if(!is_array($a))
    $a2[0][0] = $a;
  else{
    if(!is_array($a[0])) $a2[0] = $a; // $a is 1 dim array
    else $a2 = $a; // $a is a 2 dim array
  }
  //
  // Compute $nbRows
  if($layout=="h"){
    $nbRows = count($a2);
  }
  else{ // vertical layout
    for($i = 0; $i < count($a2); $i++){
      $count[] = count($a2[$i]);
    }
    $nbRows = max($count);
  }
//echo "<PRE>in TABLE, a2 : "; print_r($a2); echo "</PRE>"; echo "<BR>nbRows : $nbRows";
  //
  // Transform $tdAttr in an array if necessary
  if(!is_array($tdAttr)){ // $tdAttr is a scalar value
    $tmp = $tdAttr; // remember initial value
    for($i = 0; $i < $nbRows; $i++){
      if($layout =="h"){// horizontal layout
        for($j = 0; $j < count($a2[$i]); $j++){
          $tdAttr2[$i][$j] = $tmp; // an array is built from the unique value
        }
      }
      else{ // vertical layout
        for($j = 0; $j < count($a2); $j++){
          $tdAttr2[$j][$i] = $tmp; // an array is built from the unique value
        }
      }
    }
  }
  else{
    if(!is_array($tdAttr[0])){ // 1 dim array
      $tdAttr2[0] = $tdAttr; // transform to a 2 dim array
    }
    else{
      $tdAttr2 = $tdAttr; // check on dimensions not performed
    }
  }
//echo "<PRE>"; print_r($tdAttr2); echo "</PRE>";
  //
  // Echo the output - We work now with $a2 and $tdAttr2
  $strRes = "<table $attrs>\n";
  if($layout=="h"){
    for($i = 0; $i < $nbRows; $i++){
      $strRes .= "<tr>\n";
      for($j = 0; $j < count($a2[$i]); $j++){
        if($j < count($a2[$i])) $content = $a2[$i][$j];
        else $content = "&nbsp;";
        $strRes .= "<td " . $tdAttr2[$i][$j] . ">" . $content . "</td>\n";
      }
      $strRes .= "</tr>\n";
    }
  }
  else{ // vertical layout
    for($i = 0; $i < $nbRows; $i++){
      $strRes .= "<tr>\n";
      for($j = 0; $j < count($a2); $j++){
        if($i < count($a2[$j])) $content = $a2[$j][$i];
        else $content = "&nbsp;";
        $strRes .= "<td " . $tdAttr2[$j][$i] . ">" . $content . "</td>\n";
      }
      $strRes .= "</tr>\n";
    }
  }
  $strRes .= "</table>\n";
  //
  return $strRes;
} // end TABLE


//******************** TEXTAREA *******************************
/** Builds a TEXTAREA tag. */
function TEXTAREA($name, $contents="", $otherAttrs=""){
  if($otherAttrs != "") $otherAttrs = " " . $otherAttrs;
  return '<textarea name="' . $name . '"' . $otherAttrs . ">$contents</textarea>\n";
} // end TEXTAREA


?>