<?php
// Software released under the General Public License (version 3 or later), available at
// http://www.gnu.org/copyleft/gpl.html
/******************************************************************************
Conversion of latitudes between formats used by JeTheme.
See <a href='todo'>Longitude and latitude formats</a>.

@license  GPL
@author   <a href="http://www.tig12.net">Thierry Graff</a>
@history  2008.05.20, 16h01 : Creation
********************************************************************************/
class Latitudes{
  
  
  //********************* convert ******************************
  /**
    Converts latitudes between the formats used in JeTheme
    @param $long The latitude, expressed in <code>$inputFormat</code>
    @param $inputFormat Format in which $long is expressed
                  Can be 'decimal', 'db', 'user'
    @param $outputFormat Format of $long
                  Can be 'decimal', 'db', 'user'
    @return $long converted in <code>$outputFormat</code>
    @throws Exception if $inputFormat or $outputFormat are incorrect
                   Exception if latitude is not valid
    @todo Finish implementation
  */
  public static function convert($lat, $inputFormat, $outputFormat){
    if(!in_array($inputFormat, array('decimal', 'db', 'user')))
      throw new InvalidArgumentException("invalid parameter \$inputFormat : <b>$inputFormat</b>"); 
    if(!in_array($outputFormat, array('decimal', 'db', 'user')))
      throw new InvalidArgumentException("invalid parameter \$outputFormat : <b>$outputFormat</b>");
    $lat = trim($lat);
    switch($inputFormat){
      case 'user' :
        switch($outputFormat){
          case 'db' : return self::user2db($lat); break;
          case 'decimal' : return self::user2decimal($lat); break;
        }
      break;
      case 'db' :
        // not implemented
      break;
      case 'decimal' :
        // not implemented
      break;
    }
  }// end convert
  
  
  // *************************** user2db ***************************
  /**
    @param $lat Latitude in user format
    @return $lat in db format
    @todo not implemented
  */
  private static function user2db($lat){
  }// end user2db
  
  
  // *************************** user2decimal ***************************
  /**
    @param $lat String Latitude in user format
    @return $lat in decimal format
  */
  private static function user2decimal($lat){
    $array = self::parseUserLat($lat);
    $res = $array[1] + $array[2] / 60 + $array[3] / 3600;
    return $res * ($array[0] == '-' ? -1 : 1);
  }// end user2decimal
  
  
  // =======================================================================
  //                                                                        Auxiliary methods
  // =======================================================================
  
  // *************************** parseUserLat ***************************
  /**
    Parses a latitude expressed in user format.
    @param $long String Latitude in user format
    @return Array containing the parsed latitude
                  Contains 4 elements : sign (+ or -); degrees ; minutes ; seconds
                  If minutes or seconds are not specified, the entries contain empty strings.
    @throws Exception if the latitude is not correctly formatted
  */
  private static function parseUserLat($lat){
    $res = array('', '', '', ''); // if minutes or seconds not specified, empty string in the res
    //
    $sign = '';
    $test = substr($lat, 0, 1);
    $lat2 = $lat; // keep $lat for the error msg
    if($test == '-' || $test == '+'){
      $sign = $test;
      $lat2 = substr($lat2, 1);
    }
    //
    $NS = '';
    $test = substr($lat2, -1, 1);
    if($test == 'n' || $test == 'N' || $test == 's' || $test == 'S'){
      $NS = strToUpper($test);
      $lat2 = substr($lat2, 0, -1);
    }
    //
    if($sign != '' && $NS != '')
      throw new Exception("Wrong format for latitude <b>$lat</b> : impossible to specify both <b>$sign</b> and <b>$NS</b>");
    if($sign != ''){
      $res[0] = $sign;
    }
    else{
      if($NS == 'N') $res[0] = '+';
      else if($NS == 'S') $res[0] = '-';
      else  $res[0] = '+'; // $NS = ''
    }
    //
    $pieces = preg_split('/\D/', $lat2, -1, PREG_SPLIT_NO_EMPTY);
    if(count($pieces) > 3)
      throw new Exception("Wrong format for latitude <b>$lat</b>");
    // degrees
    if(isset($pieces[0])){
      if($pieces[0] > 90) throw new Exception("Wrong format for latitude <b>$lat</b> : degrees must be inferior to 90");
      $res[1] = $pieces[0];
    }
    // minutes
    if(isset($pieces[1])){
      if($pieces[1] > 59) throw new Exception("Wrong format for latitude <b>$lat</b> : minutes must be inferior to 60");
      $res[2] = $pieces[1];
    }
    // seconds
    if(isset($pieces[2])){
      if($pieces[2] > 59) throw new Exception("Wrong format for latitude <b>$lat</b> : seconds must be inferior to 60");
      $res[3] = $pieces[2];
    }
    return $res;
  }// end parseUserLat
  
}//end class

?>
